aboutsummaryrefslogtreecommitdiff
path: root/mod
diff options
context:
space:
mode:
authorpete <pete@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-03-19 12:06:14 +0000
committerpete <pete@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-03-19 12:06:14 +0000
commit758b3d02a727ae19b8f45c39a906ed7a8776ea1d (patch)
treeb6d7c7e5dd6139ebc70550fa856a244f4c68f9aa /mod
parent94ccaa1a5f6c927674698f1788f95241dce5bc29 (diff)
downloadelgg-758b3d02a727ae19b8f45c39a906ed7a8776ea1d.tar.gz
elgg-758b3d02a727ae19b8f45c39a906ed7a8776ea1d.tar.bz2
Updated latest comments to new UI and coding standards, and added to Blog and Files sidebar.
git-svn-id: http://code.elgg.org/elgg/trunk@5442 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'mod')
-rw-r--r--mod/blog/views/default/blog/sidebar_menu.php11
-rw-r--r--mod/file/friends.php7
-rw-r--r--mod/file/index.php7
-rw-r--r--mod/file/world.php6
4 files changed, 23 insertions, 8 deletions
diff --git a/mod/file/friends.php b/mod/file/friends.php
index eff4a4aa0..763df85f9 100644
--- a/mod/file/friends.php
+++ b/mod/file/friends.php
@@ -30,8 +30,13 @@
} else {
$area2 .= $content;
}
+
+ //get the latest comments on all files
+ $comments = get_annotations(0, "object", "file", "generic_comment", "", 0, 4, 0, "desc");
+ $area3 = elgg_view('annotation/latest_comments', array('comments' => $comments));
+
$content = "<div class='files'>".$area1.$area2."</div>";
- $body = elgg_view_layout('one_column_with_sidebar', $content);
+ $body = elgg_view_layout('one_column_with_sidebar', $content, $area3);
page_draw($title, $body);
?> \ No newline at end of file
diff --git a/mod/file/index.php b/mod/file/index.php
index e05f98eb2..6a418ac6a 100644
--- a/mod/file/index.php
+++ b/mod/file/index.php
@@ -37,8 +37,13 @@
} else {
$area2 .= "<p class='margin_top'>".elgg_echo("file:none")."</p>";
}
+
+ //get the latest comments on the current users files
+ $comments = get_annotations(0, "object", "file", "generic_comment", "", 0, 4, 0, "desc",0,0,page_owner());
+ $area3 = elgg_view('annotation/latest_comments', array('comments' => $comments));
+
$content = "<div class='files'>".$area1.$area2."</div>";
- $body = elgg_view_layout('one_column_with_sidebar', $content);
+ $body = elgg_view_layout('one_column_with_sidebar', $content, $area3);
page_draw($title, $body);
?> \ No newline at end of file
diff --git a/mod/file/world.php b/mod/file/world.php
index bd39d2a08..38ab4e8ff 100644
--- a/mod/file/world.php
+++ b/mod/file/world.php
@@ -32,10 +32,14 @@
else
$area2 .= elgg_list_entities(array('types' => 'object', 'subtypes' => 'file', 'limit' => 10, 'offset' => $offset, 'full_view' => FALSE));
set_context('file');
+
+ //get the latest comments on all files
+ $comments = get_annotations(0, "object", "file", "generic_comment", "", 0, 4, 0, "desc");
+ $area3 = elgg_view('annotation/latest_comments', array('comments' => $comments));
$content = "<div class='files'>".$area1.$area2."</div>";
- $body = elgg_view_layout('one_column_with_sidebar', $content);
+ $body = elgg_view_layout('one_column_with_sidebar', $content, $area3);
// Finally draw the page
page_draw($title, $body);
diff --git a/mod/blog/views/default/blog/sidebar_menu.php b/mod/blog/views/default/blog/sidebar_menu.php
index 8ecec9a53..d4f67ec98 100644
--- a/mod/blog/views/default/blog/sidebar_menu.php
+++ b/mod/blog/views/default/blog/sidebar_menu.php
@@ -31,13 +31,14 @@ Owned blogs;
$loggedin_user = get_loggedin_user();
$page_owner = page_owner_entity();
-?>
-
-<?php
// include a view for plugins to extend
echo elgg_view("blogs/sidebar", array("object_type" => 'blog'));
-?>
-<?php // temporarily force tag-cloud display
+
+ // fetch & display latest comments on all blog posts
+ $comments = get_annotations(0, "object", "blog", "generic_comment", "", 0, 4, 0, "desc");
+ echo elgg_view('annotation/latest_comments', array('comments' => $comments));
+
+ // temporarily force tag-cloud display
echo "<h3>Tagcloud</h3>";
echo "<div class='tagcloud sidebar'>".display_tagcloud(0, 100, 'tags')."</div>";
echo "<a href=\"{$vars['url']}mod/tagcloud/tagcloud.php\">All site tags</a>";